package com.ssj.dao.sys.fx.dao;

import com.ssj.service.conch.parents.v1.dto.PositionSchoolV1Dto;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.List;
import java.util.Map;

public interface FxQueryDao {

    Page<Map<String, Object>> findSaleCountList(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> salseMouthtList(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> salseMouthMoneytList(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> salsetList(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> findByPageMap(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> findTemplateByPageMap(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> findMaterielLeafByPageMap(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> findMaterielOffLeafByPageMap(Map<String, Object> params, Pageable initPage);

    List<Map<String, Object>> findMapList(Map<String, Object> params);

    Page<Map<String, Object>> vipDerverList(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> MonthInAndOutList(Map<String, Object> params, Pageable initPage);

    List<Map<String, Object>> monthInAndOutDetailList(Map<String, Object> params);
    
    Page<Map<String, Object>> findDeviceActivationList(Map<String, Object> params, Pageable pageable);

    Page<Map<String, Object>> findForPageList(Map<String, Object> params, Pageable initPage);
    
    
    Page<Map<String, Object>> findDeviceActCountListPage(Map<String, Object> params, Pageable pageable);
    
    Page<Map<String, Object>> findDeviceActDetailsPage(Map<String, Object> params, Pageable pageable);
    
    Page<Map<String, Object>> deviceUnloadingList(Map<String, Object> params, Pageable pageable);

    List<PositionSchoolV1Dto> findSchoolList(String libId);

    Page<Map<String, Object>> deviceInAndOutList(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> deviceOutList(Map<String, Object> params, Pageable initPage);
    
    Page<Map<String, Object>> findMerchantSignOrderByPage(Map<String, Object> params, Pageable initPage);
    
    Page<Map<String, Object>> findMerchantSignByPage(Map<String, Object> params, Pageable initPage);
    
    Page<Map<String, Object>> findMerchantSignStatusByPage(Map<String, Object> params, Pageable initPage);
    
    
    Page<Map<String, Object>> findMerchantMealOrderPage(Map<String, Object> params, Pageable initPage);
    
    Page<Map<String, Object>> findMerchantMealPage(Map<String, Object> params, Pageable initPage);
    
    Page<Map<String, Object>> findMerchantMealStatusPage(Map<String, Object> params, Pageable initPage);
    
    Page<Map<String, Object>> findMerchantCapByPage(Map<String, Object> params, Pageable initPage);
    
    
    Page<Map<String, Object>> findMerchantPlatOrderByPage(Map<String, Object> params, Pageable initPage);
    
    
}
